@@ -94,6 +94,7 @@ struct UICStruct {
 	gint callDetected;
 	gboolean smsDeliveryReport;
 	gboolean showDialPad;
+	gboolean fullScreen;
 };
 typedef struct UICStruct UIComponents;
 
@@ -123,6 +124,7 @@ static void  quit_event( UIComponents *uic, guint callback_action, GtkWidget *me
 	gconf_client_set_bool(gconf_client, GCONF_NOTIFY_CALL_KEY, uic->getCalls, NULL);
 	gconf_client_set_bool(gconf_client, GCONF_NOTIFY_SMS_KEY, uic->getSms, NULL);
 	gconf_client_set_bool(gconf_client, GCONF_SHOW_DIALPAD_KEY, uic->showDialPad, NULL);
+	gconf_client_set_bool(gconf_client, GCONF_FULL_SCREEN_KEY, uic->fullScreen, NULL);
 	gconf_client_suggest_sync (gconf_client, NULL);
 	g_object_unref (gconf_client);
 
@@ -1141,6 +1143,21 @@ gboolean clearSMSTextView_cb(GtkTextView *smsTextView, GdkEventFocus *event, UIC
 	return FALSE;
 }
 
+/* Callback for hardware keys */
+gboolean key_press_cb(GtkWidget * widget, GdkEventKey * event, UIComponents *uic) {
+    switch (event->keyval) {
+    case GDK_F6:
+	if (uic->fullScreen) {
+		gtk_window_unfullscreen(GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+	} else {
+		gtk_window_fullscreen(GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+	}
+	uic->fullScreen = !uic->fullScreen;
+        return TRUE;
+    }
+
+    return FALSE;
+}
 
 int main( int argc, char *argv[] ) {
 	    /* GtkWidget is the storage type for widgets */
@@ -1186,6 +1203,7 @@ int main( int argc, char *argv[] ) {
 	uic->getCalls = gconf_client_get_bool(gconf_client, GCONF_NOTIFY_CALL_KEY, NULL);
 	uic->getSms = gconf_client_get_bool(gconf_client, GCONF_NOTIFY_SMS_KEY, NULL);
 	uic->showDialPad = gconf_client_get_bool(gconf_client, GCONF_SHOW_DIALPAD_KEY, NULL);
+	uic->fullScreen = gconf_client_get_bool(gconf_client, GCONF_FULL_SCREEN_KEY, NULL);
 
 /* Gnokii : read the config */
 	gn_error err;
@@ -1242,7 +1260,11 @@ int main( int argc, char *argv[] ) {
 	*      * exits GTK. */
 	g_signal_connect (G_OBJECT (appview), "delete_event",
 		      G_CALLBACK (delete_event), (gpointer) uic);
-
+	
+	/* Add hardware button listener to application */
+	g_signal_connect(G_OBJECT(appview), "key_press_event", 
+			G_CALLBACK(key_press_cb), (gpointer) uic);
+	
 	// Menus
 	hildon_window_set_menu (appview, create_menus (uic));
 
@@ -1437,6 +1459,10 @@ int main( int argc, char *argv[] ) {
 		}
 	}
 	
+	if (uic->fullScreen) {
+		gtk_window_fullscreen(GTK_WINDOW(appview));
+	}
+	
 	/* Rest in gtk_main and wait for the fun to begin! */
 	gtk_main ();
 
